@@ -33,6 +33,20 @@ InitConstraint.degrees<-InitConstraint.nodedegrees<-function(conlist){
    conlist
 }
 
+InitConstraint.degreesTetrad<-function(conlist){
+   if (nargs()>1)
+     stop(paste("Vertex degreesTetrad constraint does not take arguments at this time."), call.=FALSE)
+   conlist$degreesTetrad<-list()
+   conlist
+}
+
+InitConstraint.degreesHexad<-function(conlist){
+   if (nargs()>1)
+     stop(paste("Vertex degreesHexad constraint does not take arguments at this time."), call.=FALSE)
+   conlist$Hexad<-list()
+   conlist
+}
+
 InitConstraint.degreedist<-function(conlist){
    if (nargs()>1)
      stop(paste("Degree distribution constraint does not take arguments at this time."), call.=FALSE)
