@@ -160,30 +160,6 @@ InitMHP.HammingTNT <- function(arguments, nw, model) {
   MHproposal
 }
 
-InitMHP.formation <- function(arguments, nw, model) {
-  MHproposal <- list(name = "Formation", args=NULL, package="ergm")
-  if(is.bipartite(nw)){
-    MHproposal$name <- "BipartiteFormation"
-  }
-  MHproposal
-}
-
-InitMHP.formationTNT <- function(arguments, nw, model) {
-  MHproposal <- list(name = "FormationTNT", args=NULL, package="ergm")
-  if(is.bipartite(nw)){
-    MHproposal$name <- "BipartiteFormationTNT"
-  }
-  MHproposal
-}
-
-InitMHP.dissolution <- function(arguments, nw, model) {
-  MHproposal <- list(name = "Dissolution", args=NULL, package="ergm")
-  if(is.bipartite(nw)){
-    MHproposal$name <- "BipartiteDissolution"
-  }
-  MHproposal
-}
-
 InitMHP.randomtoggleNonObserved <- function(arguments, nw, model) {
   MHproposal <- list(name = "randomtoggleNonObserved", args=NULL, package="ergm")
   if(is.bipartite(nw)){
