@@ -7,8 +7,7 @@
 #
 #  Copyright 2010 the statnet development team
 ######################################################################
-anova.ergmlist <-
-  function (object, ..., scale = 0, test = "F") 
+anova.ergmlist <- function (object, ..., scale = 0, test = "F") 
 {
   objects <- list(object, ...)
   responses <- as.character(lapply(objects, function(x) deparse(x$formula[[2]])))
