@@ -9,6 +9,7 @@
 ######################################################################
 ergm.initialfit<-function(theta0, MLestimate, Clist, Clist.miss, m, 
                           MPLEtype="glm", initial.loglik=NULL,
+                          conddeg=NULL, MCMCparams=NULL, MHproposal=NULL,
                           force.MPLE=FALSE,
                           verbose=FALSE, ...) {
 # Process input for call to ergm.mple or some other alternative fitting
@@ -30,7 +31,8 @@ ergm.initialfit<-function(theta0, MLestimate, Clist, Clist.miss, m,
 
     if(force.MPLE){
       fit <- ergm.mple(Clist, Clist.miss, m, MPLEtype=MPLEtype,
-                       theta0=theta0,
+                       theta0=theta0, conddeg=conddeg, 
+		       MCMCparams=MCMCparams, MHproposal=MHproposal,
                        verbose=verbose, ...)
     }else{    
       if(!is.null(Clist.miss)){
@@ -49,7 +51,9 @@ ergm.initialfit<-function(theta0, MLestimate, Clist, Clist.miss, m,
   } else {
     if (fitmethod==1) {  #  MPLE
       fit <- ergm.mple(Clist, Clist.miss, m, MPLEtype=MPLEtype,
-                       verbose=verbose, ...)
+                       conddeg=conddeg, 
+		       MCMCparams=MCMCparams, MHproposal=MHproposal,
+		       verbose=verbose, ...)
     }
   }
   fit
