@@ -22,10 +22,16 @@ llik.fun <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NULL,
   # i.e., assuming that the network statistics are approximately normally 
   # distributed so that exp(eta * stats) is lognormal
   x <- eta-eta0
+# MSH: Is this robust?
+  x <- x[!etamap$offsetmap]
+  xsim <- xsim[,!etamap$offsetmap, drop=FALSE]
+  xobs <- xobs[!etamap$offsetmap]
+  #
   basepred <- xsim %*% x
   mb <- sum(basepred*probs)
   vb <- sum(basepred*basepred*probs) - mb*mb
   llr <- sum(xobs * x) - mb - varweight*vb
+  #
 
   # Simplistic error control;  -800 is effectively like -Inf:
   if(is.infinite(llr) | is.na(llr)){llr <- -800}
@@ -39,49 +45,95 @@ llik.fun <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NULL,
   }
 }
 
+#llik.grad <- function(theta, xobs, xsim, probs,  xsim.miss=NULL, probs.miss=NULL,
+#                      varweight=0.5, trustregion=20, eta0, etamap){
+#  theta.offset <- etamap$theta0
+#  theta.offset[!etamap$offsettheta] <- theta
+#  eta <- ergm.eta(theta.offset, etamap)
+#  x <- eta-eta0
+#  xsim[,etamap$offsetmap] <- 0
+#  basepred <- xsim %*% x
+#  prob <- max(basepred)
+#  prob <- probs*exp(basepred - prob)
+#  prob <- prob/sum(prob)
+#  E <- apply(sweep(xsim, 1, prob, "*"), 2, sum)
+#  llg <- xobs - E
+#  llg[is.na(llg) | is.infinite(llg)] <- 0
+##
+## Penalize changes to trustregion
+##
+## llg <- llg - 2*(llg-trustregion)*(llg>trustregion)
+## 
+## The next lines are for the Hessian which optim does not use
+##
+## vtmp <- sweep(sweep(xsim, 2, E, "-"), 1, sqrt(prob), "*")
+## V <- -t(vtmp) %*% vtmp
+## list(gradient=xobs-E,hessian=V)
+## print(ergm.etagradmult(theta.offset, llg, etamap))
+#  llg <- ergm.etagradmult(theta.offset, llg, etamap)
+#  llg[!etamap$offsettheta]
+#}
 llik.grad <- function(theta, xobs, xsim, probs,  xsim.miss=NULL, probs.miss=NULL,
                       varweight=0.5, trustregion=20, eta0, etamap){
   theta.offset <- etamap$theta0
   theta.offset[!etamap$offsettheta] <- theta
   eta <- ergm.eta(theta.offset, etamap)
+# etagrad <- ergm.etagrad(theta.offset, etamap)
   x <- eta-eta0
-  xsim[,etamap$offsetmap] <- 0
+# MSH: Is this robust?
+  x <- x[!etamap$offsetmap]
+  xsim <- xsim[,!etamap$offsetmap, drop=FALSE]
+  xobs <- xobs[!etamap$offsetmap]
+# etagrad <- etagrad[,!etamap$offsetmap,drop=FALSE]
+# etagrad <- etagrad[!etamap$offsettheta,,drop=FALSE]
+#
   basepred <- xsim %*% x
   prob <- max(basepred)
   prob <- probs*exp(basepred - prob)
   prob <- prob/sum(prob)
   E <- apply(sweep(xsim, 1, prob, "*"), 2, sum)
-  llr <- xobs - E
-  llr[is.na(llr) | is.infinite(llr)] <- 0
+  llg <- xobs - E
+  llg[is.na(llg) | is.infinite(llg)] <- 0
 #
 # Penalize changes to trustregion
 #
-# llr <- llr - 2*(llr-trustregion)*(llr>trustregion)
+# llg <- llg - 2*(llg-trustregion)*(llg>trustregion)
 # 
 # The next lines are for the Hessian which optim does not use
 #
 # vtmp <- sweep(sweep(xsim, 2, E, "-"), 1, sqrt(prob), "*")
-# V <- t(vtmp) %*% vtmp
+# V <- -t(vtmp) %*% vtmp
 # list(gradient=xobs-E,hessian=V)
-# print(ergm.etagradmult(theta.offset, llr, etamap))
-  llr <- ergm.etagradmult(theta.offset, llr, etamap)
-  llr[!etamap$offsettheta]
+# print(ergm.etagradmult(theta.offset, llg, etamap))
+  llg.offset <- rep(0,length(etamap$offsetmap))
+  llg.offset[!etamap$offsetmap] <- llg
+  llg <- ergm.etagradmult(theta.offset, llg.offset, etamap)
+# llg <- crossprod(llg, t(etagrad))
+# llg <- etagrad %*% llg
+# print(llg)
+  llg[!etamap$offsettheta]
 }
 
 llik.hessian <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NULL,
-                         varweight=0.5, eta0, etamap){
-# theta.offset <- etamap$theta0
-# theta.offset[!etamap$offsettheta] <- theta
+                         varweight=0.5, trustregion=20, eta0, etamap){
+  theta.offset <- etamap$theta0
+  theta.offset[!etamap$offsettheta] <- theta
   namesx <- names(theta)
 # xsim[,etamap$offsettheta] <- 0
-  xsim <- xsim[,!etamap$offsettheta, drop=FALSE]
 #
 #    eta transformation
 #
-  eta <- ergm.eta(theta, etamap)
-  etagrad <- ergm.etagrad(theta, etamap)
+  eta <- ergm.eta(theta.offset, etamap)
+# etagrad <- ergm.etagrad(theta.offset, etamap)
   x <- eta-eta0
-  x <- x[!etamap$offsettheta]
+# MSH: Is this robust?
+  x <- x[!etamap$offsetmap]
+  xsim <- xsim[,!etamap$offsetmap, drop=FALSE]
+  xobs <- xobs[!etamap$offsetmap]
+# etagrad <- etagrad[,!etamap$offsetmap,drop=FALSE]
+# etagrad <- etagrad[!etamap$offsettheta,,drop=FALSE]
+#
+# x <- x[!etamap$offsettheta]
   basepred <- xsim %*% x
   prob <- max(basepred)
   prob <- probs*exp(basepred - prob)
@@ -89,15 +141,29 @@ llik.hessian <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss=NU
   E <- apply(sweep(xsim, 1, prob, "*"), 2, sum)
 # 
   htmp <- sweep(sweep(xsim, 2, E, "-"), 1, sqrt(prob), "*")
-  htmp <- htmp %*% t(etagrad)
-  H <- - t(htmp) %*% htmp
-  He <- matrix(NA, ncol = length(theta), nrow = length(theta))
+# htmp <- htmp %*% t(etagrad)
+# H <- - t(htmp) %*% htmp
+# htmp <- etagrad %*% t(htmp)
+# H <- - htmp %*% t(htmp)
+# htmp <- tcrossprod(etagrad, htmp)
+  htmp.offset <- matrix(0, ncol = length(etamap$offsetmap), nrow = nrow(htmp))
+  htmp.offset[,!etamap$offsetmap] <- htmp
+  htmp.offset <- t(ergm.etagradmult(theta.offset, t(htmp.offset), etamap))
+# Notice the negative sign!
+  H <- -crossprod(htmp.offset, htmp.offset)
+# H <- -tcrossprod(htmp.offset, htmp.offset)
+# H <- -tcrossprod(htmp, htmp)
+# htmp <- tcrossprod(htmp, etagrad)
+# H <- crossprod(htmp, htmp)
+# H <- crossprod(t(etagrad),crossprod(H, t(etagrad)))
+  He <- matrix(NA, ncol = length(etamap$offsettheta), 
+                   nrow = length(etamap$offsettheta))
   He[!etamap$offsettheta, !etamap$offsettheta] <- H
   dimnames(He) <- list(names(namesx), names(namesx))
+# H
   He
 }
 
-
 # Use the naive approximation to the Hessian matrix.  
 # Namely, (sum_i w_i g_i)(sum_i w_i g_i)^t - sum_i(w_i g_i g_i^t)
 # where g_i is the ith vector of statistics and
@@ -125,7 +191,7 @@ llik.hessian.naive <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.m
   
   # One last step, for the case of a curved EF:  Front- and back-multiply by
   # the gradient of eta(theta).
-  H <- crossprod(etagrad, crossprod(H, etagrad))
+  H <- - crossprod(etagrad, crossprod(H, etagrad))
   He <- matrix(NA, ncol = length(theta), nrow = length(theta))
   He[!etamap$offsettheta, !etamap$offsettheta] <- H
   dimnames(He) <- list(names(namesx), names(namesx))
@@ -255,8 +321,17 @@ llik.fun.median <- function(theta, xobs, xsim, probs, xsim.miss=NULL, probs.miss
                      varweight=0.5, trustregion=20, eta0, etamap){
   theta.offset <- etamap$theta0
   theta.offset[!etamap$offsettheta] <- theta
+  # Convert theta to eta
   eta <- ergm.eta(theta.offset, etamap)
+
+  # Calculate approximation to l(eta) - l(eta0) using a lognormal approximation
+  # i.e., assuming that the network statistics are approximately normally 
+  # distributed so that exp(eta * stats) is lognormal
   x <- eta-eta0
+# MSH: Is this robust?
+  x <- x[!etamap$offsetmap]
+  xsim <- xsim[,!etamap$offsetmap, drop=FALSE]
+  xobs <- xobs[!etamap$offsetmap]
 # The next line is right!
 # aaa <- sum(xobs * x) - log(sum(probs*exp(xsim %*% x)))
 # These lines standardize:
