@@ -5,12 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) in
 #    http://statnetproject.org/attribution
 #
-# Copyright 2003 Mark S. Handcock, University of Washington
-#                David R. Hunter, Penn State University
-#                Carter T. Butts, University of California - Irvine
-#                Steven M. Goodreau, University of Washington
-#                Martina Morris, University of Washington
-# Copyright 2007 The statnet Development Team
+#  Copyright 2010 the statnet development team
 ######################################################################
 summary.formula <- function(object, ...){
   current.warn <- options()$warn
@@ -57,11 +52,7 @@ summary.statistics.network <- function(object,...,drop=FALSE, basis=NULL) {
     trms <- terms(formula)
     if(length(trms)>2){
       parent <- sys.parent()
-      nw <- try(eval(trms[[2]],parent), silent = TRUE)
-      while(inherits(nw,"try-error") & parent > 1){
-        parent <- parent - 1
-        nw <- try(eval(trms[[2]],parent), silent = TRUE)
-      }
+      nw <- ergm.getnetwork(formula)
       if (inherits(nw, "try-error")) {
         stop(trms[[2]], " is not a network or network.series object")
       }
